@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.gkeconnect.gateway_v1beta1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -163,9 +174,9 @@ class GatewayServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, GatewayServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the gateway service client.
@@ -209,10 +220,10 @@ class GatewayServiceAsyncClient:
 
     async def get_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""GetResource performs an HTTP GET request on the
@@ -245,7 +256,7 @@ class GatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.api.httpbody_pb2.HttpBody, dict]):
+            request (Optional[Union[google.api.httpbody_pb2.HttpBody, dict]]):
                 The request object. Message that represents an arbitrary
                 HTTP body. It should only be used for payload formats
                 that can't be represented as JSON, such as raw binary or
@@ -374,10 +385,10 @@ class GatewayServiceAsyncClient:
 
     async def post_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PostResource performs an HTTP POST on the Kubernetes
@@ -410,7 +421,7 @@ class GatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.api.httpbody_pb2.HttpBody, dict]):
+            request (Optional[Union[google.api.httpbody_pb2.HttpBody, dict]]):
                 The request object. Message that represents an arbitrary
                 HTTP body. It should only be used for payload formats
                 that can't be represented as JSON, such as raw binary or
@@ -539,10 +550,10 @@ class GatewayServiceAsyncClient:
 
     async def delete_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""DeleteResource performs an HTTP DELETE on the
@@ -575,7 +586,7 @@ class GatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.api.httpbody_pb2.HttpBody, dict]):
+            request (Optional[Union[google.api.httpbody_pb2.HttpBody, dict]]):
                 The request object. Message that represents an arbitrary
                 HTTP body. It should only be used for payload formats
                 that can't be represented as JSON, such as raw binary or
@@ -704,10 +715,10 @@ class GatewayServiceAsyncClient:
 
     async def put_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PutResource performs an HTTP PUT on the Kubernetes
@@ -740,7 +751,7 @@ class GatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.api.httpbody_pb2.HttpBody, dict]):
+            request (Optional[Union[google.api.httpbody_pb2.HttpBody, dict]]):
                 The request object. Message that represents an arbitrary
                 HTTP body. It should only be used for payload formats
                 that can't be represented as JSON, such as raw binary or
@@ -869,10 +880,10 @@ class GatewayServiceAsyncClient:
 
     async def patch_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PatchResource performs an HTTP PATCH on the
@@ -905,7 +916,7 @@ class GatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.api.httpbody_pb2.HttpBody, dict]):
+            request (Optional[Union[google.api.httpbody_pb2.HttpBody, dict]]):
                 The request object. Message that represents an arbitrary
                 HTTP body. It should only be used for payload formats
                 that can't be represented as JSON, such as raw binary or
@@ -1039,14 +1050,9 @@ class GatewayServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-gke-connect-gateway",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GatewayServiceAsyncClient",)
