@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.gkeconnect.gateway_v1beta1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -58,7 +70,7 @@ class GatewayServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GatewayServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -317,8 +329,8 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GatewayServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GatewayServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the gateway service client.
@@ -332,7 +344,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
             transport (Union[str, GatewayServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -362,6 +374,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -414,10 +427,10 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
     def get_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""GetResource performs an HTTP GET request on the
@@ -578,10 +591,10 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
     def post_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PostResource performs an HTTP POST on the Kubernetes
@@ -742,10 +755,10 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
     def delete_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""DeleteResource performs an HTTP DELETE on the
@@ -906,10 +919,10 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
     def put_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PutResource performs an HTTP PUT on the Kubernetes
@@ -1070,10 +1083,10 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
 
     def patch_resource(
         self,
-        request: Union[httpbody_pb2.HttpBody, dict] = None,
+        request: Optional[Union[httpbody_pb2.HttpBody, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""PatchResource performs an HTTP PATCH on the
@@ -1246,14 +1259,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-gke-connect-gateway",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GatewayServiceClient",)
